import time
import random
from . import config
from .start import main

def make_nightmare():
    message = ""
    for x in range(20):
        message += random.choice(list("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"))
    gmessage = ""
    for x in message:
        tmessage = random.choice(config.categories["random"][x.lower()])
        if x.isupper():
            tmessage = tmessage.capitalize()
        gmessage += tmessage + " "
    gmessage = gmessage.strip()
    return gmessage

if __name__ == "__main__":
    try:
        main(config)
    except KeyboardInterrupt:
        print("\nHow dare you send a ^C...")
        time.sleep(0.75)
        print(make_nightmare())


message = '"{quote}" *-{author}, {date}*'
date_format = "%d %b %Y"

categories = {
    "random": {
        "a": [
            "ass", "arse", "a",
            "anal", "analling", "aunt",
            "anime", "aelp", "aelpxy",
            "are", "annoying", "apple",
            "away"
        ],
        "b": [
            "bouncy", "butt", "boyfriend",
            "balls", "balling", "blowjob",
            "breasts", "boobs", "breast",
            "boob", "bust", "busting",
            "boy", "bruh", "bro",
            "brother", "bouncing", "boys",
            "babe", "boo", "bae",
            "bad", "baby", "babies",
            "bitch", "bitching", "bish",
            "boom", "blast", "booming"
        ],
        "c": [
            "crazy", "clitoris", "cum",
            "cumming", "coming", "come",
            "condom", "cunt", "cat",
            "craft", "chick", "chicken",
            "coder", "code", "coding",
            "chips", "chat"
        ],
        "d": [
            "dick", "dad", "duck",
            "ducking", "dildo", "duccy",
            "ducc", "dumb", "dream",
            "dreaming", "drunk", "drink",
            "drinking", "down", "dipshit",
            "dumbfuck", "dog", "doctor",
            "diesease", "dingus", "die",
            "death", "dying"
        ],
        "e": [
            "erecting", "erection", "e",
            "ejecting", "eject", "erect",
            "ex", "erect"
        ],
        "f": [
            "freaking", "fucking", "fancy",
            "fingering", "freak", "fuck",
            "fap", "fapping", "fart",
            "farting", "frick", "fricking",
            "fry", "fried", "finger",
            "fly", "flying"
        ],
        "g": [
            "googly", "go", "gay",
            "gaymer", "gaying", "gamer",
            "gaming", "girl", "girlfriend",
            "girls", "good", "grammar",
            "grandmother", "grandfather", "genius"
        ],
        "h": [
            "haitch", "haitching", "haitchpea",
            "hecking", "horny", "heck",
            "hammer", "hammering", "h",
            "hug", "hack", "hacking",
            "hub", "hugging", "heal",
            "heaven"
        ],
        "i": [
            "impostor", "indian", "internet",
            "image", "inspect", "inspection"
        ],
        "j": [
            "jerk", "jerking", "jeans"
        ],
        "k": [
            "kiss", "kissing", "kissed",
            "keeps", "keep"
        ],
        "l": [
            "laughing", "laugh", "lesbian",
            "lubricating", "left", "lick",
            "like", "liking", "licking",
            "live","life", "living",
            "loud", "lie", "lied",
            "lying"
        ],
        "m": [
            "masturbating", "masturbation", "mom",
            "my", "meow", "minecraft",
            "mine", "moan", "moaning"
        ],
        "n": [
            "nipples", "nigga", "nutty",
            "nutting", "nut", "none",
            "null"
        ],
        "o": [
            "oral", "oralling", "ovary",
            "orgasm", "out", "ovulating",
            "off", "owo", "of"
        ],
        "p": [
            "pea", "pee", "peeing",
            "pp", "penis", "poop",
            "poo", "pooping", "python",
            "porn", "pizza", "pant",
            "pants", "pornhub", "pog",
            "pogger", "poggers", "prank",
            "pussy", "puss", "puff",
            "puffy", "puck", "pranked",
            "pranking", "prak", "programming",
            "program", "progamer", "pro",
            "professional", "programmar",
            "potato"
        ],
        "q": [
            "question", "questioning", "quiet"
        ],
        "r": [
            "rainbow", "right", "rule34",
            "redacted", "rule", "ruling",
            "roast", "roasted", "roasting"
        ],
        "s": [
            "start", "starting", "sex",
            "sexing", "sperm", "spam",
            "semen", "squirt", "sqd",
            "squirting", "spamming", "squid",
            "shit", "shitting", "shut",
            "shutting", "sister", "step-sis",
            "step-bro", "step-sister", "step-brother",
            "step-mom", "step-mother", "step-dad",
            "step-father", "single", "simple",
            "stroke", "streak", "sing",
            "song", "sang", "sunk",
            "ship", "stop", "sparkler",
            "speak", "speaking", "scream",
            "screaming", "sus", "suspect"
        ],
        "t": [
            "time", "timing", "tit",
            "tits", "troll", "trolling",
            "tasty", "taste", "tasting",
            "the", "that", "thing",
            "toast", "toasty", "toasting",
            "toasted"
        ],
        "u": [
            "urine", "urinating", "undefined",
            "up", "uwu"
        ],
        "v": [
            "vagina", "vulva", "vibrator",
            "vibrating", "virgin", "video"
        ],
        "w": [
            "wank", "wink", "wanking",
            "winking", "work", "working",
            "wrong", "watch", "watching",
            "waste", "wasting"
        ],
        "x": [
            "xonia"
        ],
        "y": [
            "yellow", "you", "your",
            "youtube", "youtuber", "yum",
            "yummy", "yuck", "yucky",
            "yell", "yelling"
        ],
        "z": [
            "zombie", "zombieing", "zombert"
        ]
    },
    "lmao/lmfao": {
        "a": [
            "ass", "ass", "ass",
            "ass", "ass", "ass",
            "ass", "ass", "arse",
            "a", "aunt", "ass",
            "ass", "ass", "ass",
            "ass", "ass", "ass",
            "ass", "ass", "ass",
            "ass", "ass", "ass"
        ],
        "b": [
            "bouncy", "bouncy", "butt",
            "butt", "butt", "balls",
            "boobs", "breasts", "balls",
            "balls", "bouncing", "busting",
            "bro", "boy", "boys"
        ],
        "c": [
            "crazy", "cunt", "cumming",
            "condom", "cum", "cum", "cum"
        ],
        "d": [
            "dick", "dick", "dick",
            "dick", "dick", "dick",
            "dick", "dick", "dick",
            "dad", "ducking", "ducking",
            "ducking", "ducking", "ducking",
            "ducking", "ducking", "ducking",
            "duck", "duck", "duck",
            "dick", "dick", "dick",
            "dick", "dick", "dick",
            "dick", "dick", "dick",
            "dick", "dick", "dick",
            "dick", "dick", "dick",
            "dick", "dick", "dick"
        ],
        "e": [
            "e", "e", "erecting",
            "erecting", "erecting", "erecting",
            "erecting", "erecting", "erecting",
            "erection"
        ],
        "f": [
            "fancy", "fucking", "fucking",
            "fucking", "fucking", "fucking",
            "fucking", "fucking", "fucking",
            "freaking", "freaking", "fapping",
            "fapping", "fucking", "fapping",
            "fucking", "fucking", "fucking",
            "fucking", "fucking", "fucking",
            "fucking", "fucking", "fucking",
            "fucking", "fucking", "fucking",
            "fucking", "fucking", "fucking",
            "fucking", "fucking", "fucking",
            "fucking", "fucking", "fucking",
            "fucking", "fucking", "fucking",
            "fucking", "fucking", "fucking"
        ],
        "g": [
            "googly","googly", "gay",
            "gay", "gaming", "girl",
            "girls"
        ],
        "h": [
            "haitch", "h", "haitching",
            "haitchpea", "hecking", "hecking",
            "hecking", "hecking", "hecking",
            "hecking", "hecking", "hecking",
            "hecking", "hecking", "hecking",
            "horny", "horny", "horny",
            "horny", "horny", "horny",
            "hammering"
        ],
        "i": [
            "indian", "impostor", "indian"
        ],
        "j": [
            "jerking", "jeans"
        ],
        "k": [
            "kissing"
        ],
        "l": [
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "licking",
            "licking", "licking", "laughing",
            "laughing", "licking", "laughing",
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "laughing",
            "licking", "licking", "laughing",
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "laughing",
            "laughing", "laughing", "laughing"
        ],
        "m": [
            "my", "my", "my",
            "my", "my", "my",
            "my", "my", "mine",
            "my", "my", "my",
            "my", "my", "my",
            "my", "my", "my"
        ],
        "n": [
            "nigga", "nutting", "nutting",
            "nut"
        ],
        "o": [
            "off", "out", "owo",
            "off", "off", "off",
            "off", "off", "off",
            "off", "off", "off",
            "off", "off", "off",
            "off", "off", "off",
            "off", "off", "off",
            "off", "off", "off",
            "off", "off", "off"
        ],
        "p": [
            "pizza", "pizza", "penis",
            "penis", "penis", "penis",
            "pants", "pants", "pants"
        ],
        "q": [
            "questioning"
        ],
        "r": [
            "rule34", "redacted"
        ],
        "s": [
            "starting", "sex", "squirting",
            "sexing", "squirting", "shitting"
        ],
        "t": [
            "tasty", "taste", "tasting",
            "trolling"
        ],
        "u": [
            "uwu","urinating"
        ],
        "v": [
            "vagina", "vibrating", "vibrating",
            "vibrating", "vibrating", "vibrating",
            "vibrating", "vibrating", "vibrating",
            "vibrating"
        ],
        "w": [
            "wasting", "wanking", "wanking",
            "wanking", "wanking", "wanking",
            "wanking", "wanking"
        ],
        "x": [
            "xonia"
        ],
        "y": [
            "yellow", "you", "you",
            "your", "your", "your",
            "your", "your", "your",
            "your", "your", "your",
            "your", "your", "your"
        ],
        "z": [
            "zombie"
        ]
    }
}


"""
:copyright: (c) 2022-present SqdNoises
:license: MIT, see LICENSE for more details.
"""

__title__ = "auwiwftaaa"
__full_title__ = "abbreviation uhh what is word for tearing apart an abbreviation"
__author__ = "SqdNoises"
__license__ = "MIT"
__copyright__ = "Copyright 2022-present SqdNoises"
__version__ = "1.4.0"

from .start import main as start
from . import config